@@ -1,9 +1,9 @@
-
 from num2fawords import words, ordinal_words
 import re
 
 import random
 
+
 class Date2String():
 
     def __init__(self):
@@ -43,14 +43,14 @@ class Date2String():
         self.format_list = ['%Y-%m-%d', '%Y-%d-%m', '%d-%m-%Y', '%m-%d-%Y', '%Y/%m/%d', '%Y/%d/%m', '%d/%m/%Y',
                             '%m/%d/%Y']
 
-        self.date_rules = r'(((0[1-9]|1[012]|\b[1-9])[-/.](0[1-9]|[12][0-9]|3[01]|[1-9])[-/.][11-20]\d\d\d)|((0[0-9]|[12][0-9]|3[01]|\b[1-9])[-/.](0[1-9]|1[012]|[1-9])[-/.]([11-20]\d\d\d))|(([11-20]\d\d\d)[-/.](0[1-9]|1[012]|[1-9])[-/.](0[1-9]|[12][0-9]|3[01]|[1-9]\b))|(([11-20]\d\d\d)[-/.](0[1-9]|[12][0-9]|3[01]|[1-9])[-/.](0[1-9]|1[012]|[1-9]\b)))'
+        self.date_rules = r'(((0[1-9]|1[012]|\b[1-9])( )*[-/.]( )*(0[1-9]|[12][0-9]|3[01]|[1-9])( )*[-/.]( )*[11-20]\d\d\d)|((0[0-9]|[12][0-9]|3[01]|\b[1-9])( )*[-/.]( )*(0[1-9]|1[012]|[1-9])( )*[-/.]( )*([11-20]\d\d\d))|(([11-20]\d\d\d)( )*[-/.]( )*(0[1-9]|1[012]|[1-9])( )*[-/.]( )*(0[1-9]|[12][0-9]|3[01]|[1-9]\b))|(([11-20]\d\d\d)( )*[-/.]( )*(0[1-9]|[12][0-9]|3[01]|[1-9])( )*[-/.]( )*(0[1-9]|1[012]|[1-9]\b)))'
 
     def normalize(self, doc_string):
+
         normalized_string = self.find_date_part(text_line=doc_string)
 
         return normalized_string
 
-
     def find_date_part(self, text_line=""):
 
         content_new = re.sub(self.date_rules, lambda x: self.date_digit2string(x.group()), text_line)
