@@ -176,17 +176,17 @@ def word_mapper(nlp: Language, name: str, config_file: str, half_space_char):
 
 
 # -----------------------------------------------------------
-class SpellCheker:
-    def __init__(self, nlp: Language):
-        self.spell = SpellCheck()
-
-    def __call__(self, doc):
-        return self.spell.spell_corrector(doc)
-
-
-@Language.factory("spell_checker", default_config={})
-def spell_checker(nlp: Language, name: str):
-    return SpellCheker(nlp)
+# class SpellCheker:
+#     def __init__(self, nlp: Language):
+#         self.spell = SpellCheck()
+#
+#     def __call__(self, doc):
+#         return self.spell.spell_corrector(doc)
+#
+#
+# @Language.factory("spell_checker", default_config={})
+# def spell_checker(nlp: Language, name: str):
+#     return SpellCheker(nlp)
 
 
 # -----------------------------------------------------------
@@ -197,8 +197,9 @@ conf_path = os.path.dirname(os.path.realpath(__file__)) + "/config/"
 nlp.tokenizer = WhitespaceTokenizer(nlp)
 nlp.add_pipe("char_normalizer", first=True,
              config={"config_file": conf_path + 'character_mappings.json'})
-nlp.add_pipe("spell_checker", after="char_normalizer", config={})
-nlp.add_pipe("date2str", after="spell_checker", config={})
+# nlp.add_pipe("spell_checker", after="char_normalizer", config={})
+# nlp.add_pipe("date2str", after="spell_checker", config={})
+nlp.add_pipe("date2str", after="char_normalizer", config={})
 nlp.add_pipe("time2str", after="date2str", config={})
 nlp.add_pipe("num2str", after="time2str", config={})
 nlp.add_pipe("abbreviation2word", after="num2str", config={})
