@@ -370,7 +370,7 @@ class SpellCheck:
         return best_candidate, best_operation
 
     def spell_corrector(self, doc_string):
-        words = self.tokenizer.tokenize_words(self.normalizer.normalize(doc_string))
+        words = self.tokenizer.tokenize_words(doc_string)
 
         best_o_list = []
         best_candidates_list = []
